﻿using System;
using System.Collections.Generic;
using System.IO;
using System.Linq;

namespace WPFTreeView
{
    public static class DirectoryStructure 
    {
        #region Drive, File, Folder Methods
        public static List<DirectoryItem> GetLogicalDrives()
        {
            return Directory.GetLogicalDrives().Select(d => new DirectoryItem
            {
                FullPath =  d,
                Type = DirectoryItemTypeEnum.Drive
            }).ToList();
        }

        public static List<DirectoryItem> GetFolders(this string path)
        {
            var items = new List<DirectoryItem>();

            if (!Directory.Exists(path)) return new List<DirectoryItem>();

            var folders = Directory.GetDirectories(path);

            if (folders.Length > 0 )
            {
                items.AddRange(folders.Select(f => new DirectoryItem
                {
                    FullPath = f,
                    Type = DirectoryItemTypeEnum.Folder
                }));
            }
            return items;
        }

        public static List<DirectoryItem> GetFilesFolders( this string path)
        {
            var items = new List<DirectoryItem>();

            if (!Directory.Exists(path)) return new List<DirectoryItem>();

            var folders = Directory.GetDirectories(path);
            var files = Directory.GetFiles(path);

            if (folders.Length > 0)
            {
                items.AddRange(folders.Select(f => new DirectoryItem
                {
                    FullPath = f,
                    Type = DirectoryItemTypeEnum.Folder
                }));
            }

            if (files.Length > 0)
            {
                items.AddRange(files.Select(f => new DirectoryItem
                {
                    FullPath = f,
                    Type = DirectoryItemTypeEnum.File
                }));
            }
            return items;
        }
        #endregion

        #region FileFolder Helper
        /// <summary>
        /// nimmt den kompletten Pfad einer Datei oder Ordner und gibt nur deren Name zurück
        /// bei Dateien, inklusive Extension
        /// </summary>
        /// <param name="path">der Pfad zur Datei/Ordner</param>
        /// <returns></returns>
        public static string GetFileFolderName(this string path)
        {
            if (string.IsNullOrEmpty(path)) return string.Empty;

            var replacedPath = path.Replace('/', '\\');

            var lastIndexOfSlash = replacedPath.LastIndexOf('\\');

            if (lastIndexOfSlash <= 0) return path;

            return path.Substring(lastIndexOfSlash + 1);
        }
        #endregion
    }
}
