﻿using System;
using System.Collections.Generic;
using System.Collections.ObjectModel;
using System.ComponentModel;
using System.Linq;
using System.Runtime.CompilerServices;
using System.Text;
using System.Threading.Tasks;

namespace WPFTreeView
{
    public class DirectoryItemViewModel : INotifyPropertyChanged
    {
        #region Constructor

        /// <summary>
        /// default constructor
        /// </summary>
        public DirectoryItemViewModel()
        {

        }

        public DirectoryItemViewModel(string fullPath, DirectoryItemTypeEnum type)
        {
            FullPath = fullPath;
            Type = type;
            ClearDirectoryItems();
        }

        #endregion

        #region Public Properties

        #region Model Properties

        /// <summary>
        /// der volle Pfad zu diesem Item
        /// </summary>
        private string _fullPath;
        public string FullPath
        {
            get => _fullPath;
            set
            {
                if (_fullPath != value)
                {
                    _fullPath = value;
                    OnPropertyChanged(nameof(FullPath));
                }
                    
             }
        }

        /// <summary>
        /// der Name und Extension dieses Item (ohne Pfad)
        /// </summary>
        public string Name => Type == DirectoryItemTypeEnum.Drive ? FullPath : FullPath.GetFileFolderName();

        /// <summary>
        /// der Typ dieses Item
        /// </summary>
        private DirectoryItemTypeEnum _type;
        public DirectoryItemTypeEnum Type
        {
            get => _type;
            set
            {
                if(_type != value)
                {
                    _type = value;
                    OnPropertyChanged(nameof(Type));
                }

            }
        }

        #endregion

        #region INotifyPropertyChanged
        public event PropertyChangedEventHandler PropertyChanged;
        protected virtual void OnPropertyChanged([CallerMemberName] string propertyName = null)
        {
            PropertyChanged?.Invoke(this, new PropertyChangedEventArgs(propertyName));
        }
        #endregion

        #region UI Properties

        private ObservableCollection<DirectoryItemViewModel> _childItems;
        public ObservableCollection<DirectoryItemViewModel> ChildItems
        {
            get => _childItems;
            set
            {
                if(_childItems != value)
                {
                    _childItems = value;
                    OnPropertyChanged(nameof(ChildItems));
                }
            }
        }

        public bool CanExpand => Type != DirectoryItemTypeEnum.File;

        public bool IsExpanded
        {
            get => ChildItems?.Count(i => i != null) > 0;
            set
            {
                if (value == true)
                    Expand();
                else
                    ClearDirectoryItems();
                OnPropertyChanged(nameof(IsExpanded));
            }
        }
        #endregion

        #endregion

        #region Command Methods
        private void Expand()
        {

            if (Type == DirectoryItemTypeEnum.File)
                return;
            var childItems = FullPath.GetFolders();
            ChildItems = new ObservableCollection<DirectoryItemViewModel>(childItems.Select(child => new DirectoryItemViewModel(child.FullPath, child.Type)));
        }

        #endregion

        #region Helper Methods

        

        private void ClearDirectoryItems()
        {
            ChildItems = new ObservableCollection<DirectoryItemViewModel>();
            if (Type != DirectoryItemTypeEnum.File)
                ChildItems.Add(null);

        }

        #endregion
    }
}
