﻿using System;
using System.Collections.Generic;
using System.Collections.ObjectModel;
using System.ComponentModel;
using System.Linq;
using System.Runtime.CompilerServices;
using System.Text;
using System.Threading.Tasks;

namespace WPFTreeView
{
    public class MainWindowViewModel :INotifyPropertyChanged
    {
        public MainWindowViewModel()
        {
            var drives = DirectoryStructure.GetLogicalDrives();
            Items = new ObservableCollection<DirectoryItemViewModel>(
                drives.Select(drive => new DirectoryItemViewModel(drive.FullPath, DirectoryItemTypeEnum.Drive)));
        }

        #region Public Properties

        private ObservableCollection<DirectoryItemViewModel> _items;
        public ObservableCollection<DirectoryItemViewModel> Items
        {
            get => _items;
            set
            {
                if (_items != value)
                {
                    _items = value;
                    OnPropertyChanged(nameof(Items));
                }
            }
        }

        #endregion

        #region INotifyPropertyChanged
        public event PropertyChangedEventHandler PropertyChanged;
        protected virtual void OnPropertyChanged([CallerMemberName] string propertyName = null)
        {
            PropertyChanged?.Invoke(this, new PropertyChangedEventArgs(propertyName));
        }
        #endregion
    }
}
